@@ -55,6 +55,12 @@ public enum PGProperty {
       "Force use of a particular protocol version when connecting, currently only version 3 is supported.",
       false, "3"),
 
+  /**
+   * Specify 'options' connection initialization parameter.
+   * The value of this parameter may contain spaces and other special characters or their URL representation.
+   */
+  OPTIONS("options", null, "Specify 'options' connection initialization parameter."),
+
   /**
    * <p>Logger level of the driver. Allowed values: {@code OFF}, {@code DEBUG} or {@code TRACE}.</p>
    *
@@ -401,6 +407,11 @@ public enum PGProperty {
           + " like 'cached statement cannot change return type' or 'statement XXX is not valid' so JDBC driver rollsback and retries", false,
       "always", "never", "conservative"),
 
+  /**
+   *
+   */
+  CLEANUP_SAVEPOINTS("cleanupSavepoints", "false","Determine whether SAVEPOINTS used in AUTOSAVE will be released per query or not",
+      false, "true", "false"),
   /**
    * Configure optimization to enable batch insert re-writing.
    */
@@ -428,11 +439,11 @@ public enum PGProperty {
           + "from that database. "
           + "(backend >= 9.4)");
 
-  private String _name;
-  private String _defaultValue;
-  private boolean _required;
-  private String _description;
-  private String[] _choices;
+  private final String name;
+  private final String defaultValue;
+  private final boolean required;
+  private final String description;
+  private final String[] choices;
 
   PGProperty(String name, String defaultValue, String description) {
     this(name, defaultValue, description, false);
@@ -444,11 +455,11 @@ public enum PGProperty {
 
   PGProperty(String name, String defaultValue, String description, boolean required,
       String... choices) {
-    _name = name;
-    _defaultValue = defaultValue;
-    _required = required;
-    _description = description;
-    _choices = choices;
+    this.name = name;
+    this.defaultValue = defaultValue;
+    this.required = required;
+    this.description = description;
+    this.choices = choices;
   }
 
   /**
@@ -458,7 +469,7 @@ public enum PGProperty {
    * @return the name of the connection parameter
    */
   public String getName() {
-    return _name;
+    return name;
   }
 
   /**
@@ -467,7 +478,7 @@ public enum PGProperty {
    * @return the default value for this connection parameter or null
    */
   public String getDefaultValue() {
-    return _defaultValue;
+    return defaultValue;
   }
 
   /**
@@ -476,7 +487,7 @@ public enum PGProperty {
    * @return the available values for this connection parameter or null
    */
   public String[] getChoices() {
-    return _choices;
+    return choices;
   }
 
   /**
@@ -487,7 +498,7 @@ public enum PGProperty {
    * @return evaluated value for this connection parameter
    */
   public String get(Properties properties) {
-    return properties.getProperty(_name, _defaultValue);
+    return properties.getProperty(name, defaultValue);
   }
 
   /**
@@ -498,9 +509,9 @@ public enum PGProperty {
    */
   public void set(Properties properties, String value) {
     if (value == null) {
-      properties.remove(_name);
+      properties.remove(name);
     } else {
-      properties.setProperty(_name, value);
+      properties.setProperty(name, value);
     }
   }
 
@@ -571,7 +582,7 @@ public enum PGProperty {
    * @param value boolean value for this connection parameter
    */
   public void set(Properties properties, boolean value) {
-    properties.setProperty(_name, Boolean.toString(value));
+    properties.setProperty(name, Boolean.toString(value));
   }
 
   /**
@@ -581,7 +592,7 @@ public enum PGProperty {
    * @param value int value for this connection parameter
    */
   public void set(Properties properties, int value) {
-    properties.setProperty(_name, Integer.toString(value));
+    properties.setProperty(name, Integer.toString(value));
   }
 
   /**
@@ -602,10 +613,10 @@ public enum PGProperty {
    * @return a DriverPropertyInfo representing this connection parameter
    */
   public DriverPropertyInfo toDriverPropertyInfo(Properties properties) {
-    DriverPropertyInfo propertyInfo = new DriverPropertyInfo(_name, get(properties));
-    propertyInfo.required = _required;
-    propertyInfo.description = _description;
-    propertyInfo.choices = _choices;
+    DriverPropertyInfo propertyInfo = new DriverPropertyInfo(name, get(properties));
+    propertyInfo.required = required;
+    propertyInfo.description = description;
+    propertyInfo.choices = choices;
     return propertyInfo;
   }
 
@@ -626,7 +637,7 @@ public enum PGProperty {
    * @return the value of a set property
    */
   public String getSetString(Properties properties) {
-    Object o = properties.get(_name);
+    Object o = properties.get(name);
     if (o instanceof String) {
       return (String) o;
     }
