@@ -36,14 +36,19 @@ public class PGStream implements Closeable, Flushable {
   private final SocketFactory socketFactory;
   private final HostSpec hostSpec;
 
-  private final byte[] _int4buf;
-  private final byte[] _int2buf;
+  private final byte[] int4Buf;
+  private final byte[] int2Buf;
 
   private Socket connection;
-  private VisibleBufferedInputStream pg_input;
-  private OutputStream pg_output;
+  private VisibleBufferedInputStream pgInput;
+  private OutputStream pgOutput;
   private byte[] streamBuffer;
 
+  private long nextStreamAvailableCheckTime;
+  // This is a workaround for SSL sockets: sslInputStream.available() might return 0
+  // so we perform "1ms reads" once in a while
+  private int minStreamAvailableCheckDelay = 1000;
+
   private Encoding encoding;
   private Writer encodingWriter;
 
@@ -72,8 +77,8 @@ public class PGStream implements Closeable, Flushable {
     changeSocket(socket);
     setEncoding(Encoding.getJVMEncoding("UTF-8"));
 
-    _int2buf = new byte[2];
-    _int4buf = new byte[4];
+    int2Buf = new byte[2];
+    int4Buf = new byte[4];
   }
 
   /**
@@ -110,14 +115,20 @@ public class PGStream implements Closeable, Flushable {
    * @throws IOException if something wrong happens
    */
   public boolean hasMessagePending() throws IOException {
-    if (pg_input.available() > 0) {
+    if (pgInput.available() > 0) {
       return true;
     }
     // In certain cases, available returns 0, yet there are bytes
+    long now = System.currentTimeMillis();
+    if (now < nextStreamAvailableCheckTime && minStreamAvailableCheckDelay != 0) {
+      // Do not use ".peek" too often
+      return false;
+    }
+    nextStreamAvailableCheckTime = now + minStreamAvailableCheckDelay;
     int soTimeout = getNetworkTimeout();
     setNetworkTimeout(1);
     try {
-      return pg_input.peek() != -1;
+      return pgInput.peek() != -1;
     } catch (SocketTimeoutException e) {
       return false;
     } finally {
@@ -125,6 +136,10 @@ public class PGStream implements Closeable, Flushable {
     }
   }
 
+  public void setMinStreamAvailableCheckDelay(int delay) {
+    this.minStreamAvailableCheckDelay = delay;
+  }
+
   /**
    * Switch this stream to using a new socket. Any existing socket is <em>not</em> closed; it's
    * assumed that we are changing to a new socket that delegates to the original socket (e.g. SSL).
@@ -141,8 +156,8 @@ public class PGStream implements Closeable, Flushable {
     connection.setTcpNoDelay(true);
 
     // Buffer sizes submitted by Sverre H Huseby <sverrehu@online.no>
-    pg_input = new VisibleBufferedInputStream(connection.getInputStream(), 8192);
-    pg_output = new BufferedOutputStream(connection.getOutputStream(), 8192);
+    pgInput = new VisibleBufferedInputStream(connection.getInputStream(), 8192);
+    pgOutput = new BufferedOutputStream(connection.getOutputStream(), 8192);
 
     if (encoding != null) {
       setEncoding(encoding);
@@ -172,7 +187,7 @@ public class PGStream implements Closeable, Flushable {
 
     // Intercept flush() downcalls from the writer; our caller
     // will call PGStream.flush() as needed.
-    OutputStream interceptor = new FilterOutputStream(pg_output) {
+    OutputStream interceptor = new FilterOutputStream(pgOutput) {
       public void flush() throws IOException {
       }
 
@@ -209,7 +224,7 @@ public class PGStream implements Closeable, Flushable {
    * @throws IOException if an I/O error occurs
    */
   public void sendChar(int val) throws IOException {
-    pg_output.write(val);
+    pgOutput.write(val);
   }
 
   /**
@@ -219,11 +234,11 @@ public class PGStream implements Closeable, Flushable {
    * @throws IOException if an I/O error occurs
    */
   public void sendInteger4(int val) throws IOException {
-    _int4buf[0] = (byte) (val >>> 24);
-    _int4buf[1] = (byte) (val >>> 16);
-    _int4buf[2] = (byte) (val >>> 8);
-    _int4buf[3] = (byte) (val);
-    pg_output.write(_int4buf);
+    int4Buf[0] = (byte) (val >>> 24);
+    int4Buf[1] = (byte) (val >>> 16);
+    int4Buf[2] = (byte) (val >>> 8);
+    int4Buf[3] = (byte) (val);
+    pgOutput.write(int4Buf);
   }
 
   /**
@@ -237,9 +252,9 @@ public class PGStream implements Closeable, Flushable {
       throw new IOException("Tried to send an out-of-range integer as a 2-byte value: " + val);
     }
 
-    _int2buf[0] = (byte) (val >>> 8);
-    _int2buf[1] = (byte) val;
-    pg_output.write(_int2buf);
+    int2Buf[0] = (byte) (val >>> 8);
+    int2Buf[1] = (byte) val;
+    pgOutput.write(int2Buf);
   }
 
   /**
@@ -249,7 +264,7 @@ public class PGStream implements Closeable, Flushable {
    * @throws IOException if an I/O error occurs
    */
   public void send(byte[] buf) throws IOException {
-    pg_output.write(buf);
+    pgOutput.write(buf);
   }
 
   /**
@@ -275,9 +290,9 @@ public class PGStream implements Closeable, Flushable {
    */
   public void send(byte[] buf, int off, int siz) throws IOException {
     int bufamt = buf.length - off;
-    pg_output.write(buf, off, bufamt < siz ? bufamt : siz);
+    pgOutput.write(buf, off, bufamt < siz ? bufamt : siz);
     for (int i = bufamt; i < siz; ++i) {
-      pg_output.write(0);
+      pgOutput.write(0);
     }
   }
 
@@ -289,7 +304,7 @@ public class PGStream implements Closeable, Flushable {
    * @throws IOException if an I/O Error occurs
    */
   public int peekChar() throws IOException {
-    int c = pg_input.peek();
+    int c = pgInput.peek();
     if (c < 0) {
       throw new EOFException();
     }
@@ -303,7 +318,7 @@ public class PGStream implements Closeable, Flushable {
    * @throws IOException if an I/O Error occurs
    */
   public int receiveChar() throws IOException {
-    int c = pg_input.read();
+    int c = pgInput.read();
     if (c < 0) {
       throw new EOFException();
     }
@@ -317,12 +332,12 @@ public class PGStream implements Closeable, Flushable {
    * @throws IOException if an I/O error occurs
    */
   public int receiveInteger4() throws IOException {
-    if (pg_input.read(_int4buf) != 4) {
+    if (pgInput.read(int4Buf) != 4) {
       throw new EOFException();
     }
 
-    return (_int4buf[0] & 0xFF) << 24 | (_int4buf[1] & 0xFF) << 16 | (_int4buf[2] & 0xFF) << 8
-        | _int4buf[3] & 0xFF;
+    return (int4Buf[0] & 0xFF) << 24 | (int4Buf[1] & 0xFF) << 16 | (int4Buf[2] & 0xFF) << 8
+        | int4Buf[3] & 0xFF;
   }
 
   /**
@@ -332,11 +347,11 @@ public class PGStream implements Closeable, Flushable {
    * @throws IOException if an I/O error occurs
    */
   public int receiveInteger2() throws IOException {
-    if (pg_input.read(_int2buf) != 2) {
+    if (pgInput.read(int2Buf) != 2) {
       throw new EOFException();
     }
 
-    return (_int2buf[0] & 0xFF) << 8 | _int2buf[1] & 0xFF;
+    return (int2Buf[0] & 0xFF) << 8 | int2Buf[1] & 0xFF;
   }
 
   /**
@@ -347,12 +362,12 @@ public class PGStream implements Closeable, Flushable {
    * @throws IOException if something wrong happens
    */
   public String receiveString(int len) throws IOException {
-    if (!pg_input.ensureBytes(len)) {
+    if (!pgInput.ensureBytes(len)) {
       throw new EOFException();
     }
 
-    String res = encoding.decode(pg_input.getBuffer(), pg_input.getIndex(), len);
-    pg_input.skip(len);
+    String res = encoding.decode(pgInput.getBuffer(), pgInput.getIndex(), len);
+    pgInput.skip(len);
     return res;
   }
 
@@ -365,24 +380,24 @@ public class PGStream implements Closeable, Flushable {
    * @throws IOException if something wrong happens
    */
   public EncodingPredictor.DecodeResult receiveErrorString(int len) throws IOException {
-    if (!pg_input.ensureBytes(len)) {
+    if (!pgInput.ensureBytes(len)) {
       throw new EOFException();
     }
 
     EncodingPredictor.DecodeResult res;
     try {
-      String value = encoding.decode(pg_input.getBuffer(), pg_input.getIndex(), len);
+      String value = encoding.decode(pgInput.getBuffer(), pgInput.getIndex(), len);
       // no autodetect warning as the message was converted on its own
       res = new EncodingPredictor.DecodeResult(value, null);
     } catch (IOException e) {
-      res = EncodingPredictor.decode(pg_input.getBuffer(), pg_input.getIndex(), len);
+      res = EncodingPredictor.decode(pgInput.getBuffer(), pgInput.getIndex(), len);
       if (res == null) {
         Encoding enc = Encoding.defaultEncoding();
-        String value = enc.decode(pg_input.getBuffer(), pg_input.getIndex(), len);
+        String value = enc.decode(pgInput.getBuffer(), pgInput.getIndex(), len);
         res = new EncodingPredictor.DecodeResult(value, enc.name());
       }
     }
-    pg_input.skip(len);
+    pgInput.skip(len);
     return res;
   }
 
@@ -394,9 +409,9 @@ public class PGStream implements Closeable, Flushable {
    * @throws IOException if an I/O error occurs, or end of file
    */
   public String receiveString() throws IOException {
-    int len = pg_input.scanCStringLength();
-    String res = encoding.decode(pg_input.getBuffer(), pg_input.getIndex(), len - 1);
-    pg_input.skip(len);
+    int len = pgInput.scanCStringLength();
+    String res = encoding.decode(pgInput.getBuffer(), pgInput.getIndex(), len - 1);
+    pgInput.skip(len);
     return res;
   }
 
@@ -408,21 +423,20 @@ public class PGStream implements Closeable, Flushable {
    * @throws IOException if a data I/O error occurs
    */
   public byte[][] receiveTupleV3() throws IOException, OutOfMemoryError {
-    // TODO: use l_msgSize
-    int l_msgSize = receiveInteger4();
-    int l_nf = receiveInteger2();
-    byte[][] answer = new byte[l_nf][];
+    receiveInteger4(); // MESSAGE SIZE
+    int nf = receiveInteger2();
+    byte[][] answer = new byte[nf][];
 
     OutOfMemoryError oom = null;
-    for (int i = 0; i < l_nf; ++i) {
-      int l_size = receiveInteger4();
-      if (l_size != -1) {
+    for (int i = 0; i < nf; ++i) {
+      int size = receiveInteger4();
+      if (size != -1) {
         try {
-          answer[i] = new byte[l_size];
-          receive(answer[i], 0, l_size);
+          answer[i] = new byte[size];
+          receive(answer[i], 0, size);
         } catch (OutOfMemoryError oome) {
           oom = oome;
-          skip(l_size);
+          skip(size);
         }
       }
     }
@@ -459,7 +473,7 @@ public class PGStream implements Closeable, Flushable {
     int s = 0;
 
     while (s < siz) {
-      int w = pg_input.read(buf, off + s, siz - s);
+      int w = pgInput.read(buf, off + s, siz - s);
       if (w < 0) {
         throw new EOFException();
       }
@@ -470,11 +484,10 @@ public class PGStream implements Closeable, Flushable {
   public void skip(int size) throws IOException {
     long s = 0;
     while (s < size) {
-      s += pg_input.skip(size - s);
+      s += pgInput.skip(size - s);
     }
   }
 
-
   /**
    * Copy data from an input stream to the connection.
    *
@@ -524,7 +537,7 @@ public class PGStream implements Closeable, Flushable {
     if (encodingWriter != null) {
       encodingWriter.flush();
     }
-    pg_output.flush();
+    pgOutput.flush();
   }
 
   /**
@@ -534,7 +547,7 @@ public class PGStream implements Closeable, Flushable {
    * @throws SQLException if we get something other than an EOF
    */
   public void receiveEOF() throws SQLException, IOException {
-    int c = pg_input.read();
+    int c = pgInput.read();
     if (c < 0) {
       return;
     }
@@ -553,8 +566,8 @@ public class PGStream implements Closeable, Flushable {
       encodingWriter.close();
     }
 
-    pg_output.close();
-    pg_input.close();
+    pgOutput.close();
+    pgInput.close();
     connection.close();
   }
 
