@@ -37,7 +37,6 @@ import java.util.HashMap;
 import java.util.SimpleTimeZone;
 import java.util.TimeZone;
 
-
 /**
  * Misc utils for handling time and date values.
  */
@@ -512,7 +511,7 @@ public class TimestampUtils {
     }
 
     // 2) Truncate date part so in given time zone the date would be formatted as 01/01/1970
-    return convertToTime(timeMillis, useCal == null ? null : useCal.getTimeZone());
+    return convertToTime(timeMillis, useCal.getTimeZone());
   }
 
   public synchronized Date toDate(Calendar cal, String s) throws SQLException {
@@ -648,10 +647,10 @@ public class TimestampUtils {
   }
 
   private static void appendDate(StringBuilder sb, Calendar cal) {
-    int l_year = cal.get(Calendar.YEAR);
-    int l_month = cal.get(Calendar.MONTH) + 1;
-    int l_day = cal.get(Calendar.DAY_OF_MONTH);
-    appendDate(sb, l_year, l_month, l_day);
+    int year = cal.get(Calendar.YEAR);
+    int month = cal.get(Calendar.MONTH) + 1;
+    int day = cal.get(Calendar.DAY_OF_MONTH);
+    appendDate(sb, year, month, day);
   }
 
   private static void appendDate(StringBuilder sb, int year, int month, int day) {
@@ -790,7 +789,6 @@ public class TimestampUtils {
     return sbuf.toString();
   }
 
-
   public synchronized String toString(OffsetDateTime offsetDateTime) {
     if (offsetDateTime.isAfter(MAX_OFFSET_DATETIME)) {
       return "infinity";
@@ -836,7 +834,7 @@ public class TimestampUtils {
   }
 
   private static void appendDate(StringBuilder sb, LocalDate localDate) {
-    int year = Math.abs(localDate.getYear()); // year is negative for BC dates
+    int year = localDate.get(ChronoField.YEAR_OF_ERA);
     int month = localDate.getMonthValue();
     int day = localDate.getDayOfMonth();
     appendDate(sb, year, month, day);
@@ -1003,7 +1001,6 @@ public class TimestampUtils {
     return convertToTime(millis, tz); // Ensure date part is 1970-01-01
   }
 
-
   //#if mvn.project.property.postgresql.jdbc.spec >= "JDBC4.2"
   /**
    * Returns the SQL Time object matching the given bytes with {@link Oid#TIME}.
@@ -1244,13 +1241,14 @@ public class TimestampUtils {
       millis += offset;
       // 2) Truncate hours, minutes, etc. Day is always 86400 seconds, no matter what leap seconds
       // are
-      millis = millis / ONEDAY * ONEDAY;
+      millis = floorDiv(millis, ONEDAY) * ONEDAY;
       // 2) Now millis is 7 Jan 00:00 UTC, however we need that in GMT+02:00, so subtract some
       // offset
       millis -= offset;
       // Now we have brand-new 7 Jan 00:00 GMT+02:00
       return new Date(millis);
     }
+
     Calendar cal = calendarWithUserTz;
     cal.setTimeZone(tz);
     cal.setTimeInMillis(millis);
@@ -1258,6 +1256,7 @@ public class TimestampUtils {
     cal.set(Calendar.MINUTE, 0);
     cal.set(Calendar.SECOND, 0);
     cal.set(Calendar.MILLISECOND, 0);
+
     return new Date(cal.getTimeInMillis());
   }
 
@@ -1281,7 +1280,7 @@ public class TimestampUtils {
       int offset = tz.getRawOffset();
       millis += offset;
       // 2) Truncate year, month, day. Day is always 86400 seconds, no matter what leap seconds are
-      millis = millis % ONEDAY;
+      millis = floorMod(millis, ONEDAY);
       // 2) Now millis is 1970 1 Jan 15:40 UTC, however we need that in GMT+02:00, so subtract some
       // offset
       millis -= offset;
@@ -1365,7 +1364,7 @@ public class TimestampUtils {
         int years = (int) ((secs + 15773356800L) / -3155823050L);
         years++;
         years -= years / 4;
-        secs += years * 86400;
+        secs += years * 86400L;
       }
     }
 
@@ -1414,4 +1413,17 @@ public class TimestampUtils {
     }
     return TimeZone.getTimeZone(timeZone);
   }
+
+  private static long floorDiv(long x, long y) {
+    long r = x / y;
+    // if the signs are different and modulo not zero, round down
+    if ((x ^ y) < 0 && (r * y != x)) {
+      r--;
+    }
+    return r;
+  }
+
+  private static long floorMod(long x, long y) {
+    return x - floorDiv(x, y) * y;
+  }
 }
