@@ -59,12 +59,12 @@ public class GetObjectTest {
   private static final TimeZone GMT05 = TimeZone.getTimeZone("GMT-05"); // -0500 always
   private static final TimeZone GMT13 = TimeZone.getTimeZone("GMT+13"); // +1300 always
 
-  private Connection _conn;
+  private Connection conn;
 
   @Before
   public void setUp() throws Exception {
-    _conn = TestUtil.openDB();
-    TestUtil.createTable(_conn, "table1", "varchar_column varchar(16), "
+    conn = TestUtil.openDB();
+    TestUtil.createTable(conn, "table1", "varchar_column varchar(16), "
             + "char_column char(10), "
             + "boolean_column boolean,"
             + "smallint_column smallint,"
@@ -73,7 +73,7 @@ public class GetObjectTest {
             + "decimal_column decimal,"
             + "numeric_column numeric,"
             // smallserial requires 9.2 or later
-            + (((BaseConnection) _conn).haveMinimumServerVersion(ServerVersion.v9_2) ? "smallserial_column smallserial," : "")
+            + (((BaseConnection) conn).haveMinimumServerVersion(ServerVersion.v9_2) ? "smallserial_column smallserial," : "")
             + "serial_column serial,"
             + "bigserial_column bigserial,"
             + "real_column real,"
@@ -95,18 +95,18 @@ public class GetObjectTest {
             + "circle_column circle,"
             + "money_column money,"
             + "interval_column interval,"
-            + (TestUtil.haveMinimumServerVersion(_conn, ServerVersion.v8_3) ? "uuid_column uuid," : "")
+            + (TestUtil.haveMinimumServerVersion(conn, ServerVersion.v8_3) ? "uuid_column uuid," : "")
             + "inet_column inet,"
             + "cidr_column cidr,"
             + "macaddr_column macaddr"
-            + (TestUtil.haveMinimumServerVersion(_conn, ServerVersion.v8_3) ? ",xml_column xml" : "")
+            + (TestUtil.haveMinimumServerVersion(conn, ServerVersion.v8_3) ? ",xml_column xml" : "")
     );
   }
 
   @After
   public void tearDown() throws SQLException {
-    TestUtil.dropTable(_conn, "table1");
-    TestUtil.closeDB( _conn );
+    TestUtil.dropTable(conn, "table1");
+    TestUtil.closeDB(conn);
   }
 
   /**
@@ -114,7 +114,7 @@ public class GetObjectTest {
    */
   @Test
   public void testGetString() throws SQLException {
-    Statement stmt = _conn.createStatement();
+    Statement stmt = conn.createStatement();
     stmt.executeUpdate(TestUtil.insertSQL("table1","varchar_column,char_column","'varchar_value','char_value'"));
 
     ResultSet rs = stmt.executeQuery(TestUtil.selectSQL("table1", "varchar_column, char_column"));
@@ -134,11 +134,11 @@ public class GetObjectTest {
    */
   @Test
   public void testGetClob() throws SQLException {
-    Statement stmt = _conn.createStatement();
-    _conn.setAutoCommit(false);
+    Statement stmt = conn.createStatement();
+    conn.setAutoCommit(false);
     try {
       char[] data = new char[]{'d', 'e', 'a', 'd', 'b', 'e', 'e', 'f'};
-      PreparedStatement insertPS = _conn.prepareStatement(TestUtil.insertSQL("table1", "lob_column", "?"));
+      PreparedStatement insertPS = conn.prepareStatement(TestUtil.insertSQL("table1", "lob_column", "?"));
       try {
         insertPS.setObject(1, new SerialClob(data), Types.CLOB);
         insertPS.executeUpdate();
@@ -162,7 +162,7 @@ public class GetObjectTest {
         rs.close();
       }
     } finally {
-      _conn.setAutoCommit(true);
+      conn.setAutoCommit(true);
     }
   }
 
@@ -171,7 +171,7 @@ public class GetObjectTest {
    */
   @Test
   public void testGetBigDecimal() throws SQLException {
-    Statement stmt = _conn.createStatement();
+    Statement stmt = conn.createStatement();
     stmt.executeUpdate(TestUtil.insertSQL("table1","decimal_column,numeric_column","0.1,0.1"));
 
     ResultSet rs = stmt.executeQuery(TestUtil.selectSQL("table1", "decimal_column, numeric_column"));
@@ -191,7 +191,7 @@ public class GetObjectTest {
    */
   @Test
   public void testGetTimestamp() throws SQLException {
-    Statement stmt = _conn.createStatement();
+    Statement stmt = conn.createStatement();
     stmt.executeUpdate(TestUtil.insertSQL("table1","timestamp_without_time_zone_column","TIMESTAMP '2004-10-19 10:23:54'"));
 
     ResultSet rs = stmt.executeQuery(TestUtil.selectSQL("table1", "timestamp_without_time_zone_column"));
@@ -218,7 +218,7 @@ public class GetObjectTest {
    */
   @Test
   public void testGetJavaUtilDate() throws SQLException {
-    Statement stmt = _conn.createStatement();
+    Statement stmt = conn.createStatement();
     ResultSet rs = stmt.executeQuery("select TIMESTAMP '2004-10-19 10:23:54'::timestamp as timestamp_without_time_zone_column"
         + ", null::timestamp as null_timestamp");
     try {
@@ -252,7 +252,7 @@ public class GetObjectTest {
   }
 
   private void runGetTimestampWithTimeZone(TimeZone timeZone, String zoneString) throws SQLException {
-    Statement stmt = _conn.createStatement();
+    Statement stmt = conn.createStatement();
     try {
       stmt.executeUpdate(TestUtil.insertSQL("table1","timestamp_with_time_zone_column","TIMESTAMP WITH TIME ZONE '2004-10-19 10:23:54" + zoneString + "'"));
 
@@ -285,7 +285,7 @@ public class GetObjectTest {
    */
   @Test
   public void testGetCalendar() throws SQLException {
-    Statement stmt = _conn.createStatement();
+    Statement stmt = conn.createStatement();
 
     ResultSet rs = stmt.executeQuery("select TIMESTAMP '2004-10-19 10:23:54'::timestamp as timestamp_without_time_zone_column"
         + ", TIMESTAMP '2004-10-19 10:23:54+02'::timestamp as timestamp_with_time_zone_column, null::timestamp as null_timestamp");
@@ -318,7 +318,7 @@ public class GetObjectTest {
    */
   @Test
   public void testGetDate() throws SQLException {
-    Statement stmt = _conn.createStatement();
+    Statement stmt = conn.createStatement();
     stmt.executeUpdate(TestUtil.insertSQL("table1","date_column","DATE '1999-01-08'"));
 
     ResultSet rs = stmt.executeQuery(TestUtil.selectSQL("table1", "date_column"));
@@ -342,7 +342,7 @@ public class GetObjectTest {
    */
   @Test
   public void testGetTime() throws SQLException {
-    Statement stmt = _conn.createStatement();
+    Statement stmt = conn.createStatement();
     stmt.executeUpdate(TestUtil.insertSQL("table1","time_without_time_zone_column","TIME '04:05:06'"));
 
     ResultSet rs = stmt.executeQuery(TestUtil.selectSQL("table1", "time_without_time_zone_column"));
@@ -369,7 +369,7 @@ public class GetObjectTest {
    */
   @Test
   public void testGetShort() throws SQLException {
-    Statement stmt = _conn.createStatement();
+    Statement stmt = conn.createStatement();
     stmt.executeUpdate(TestUtil.insertSQL("table1","smallint_column","1"));
 
     ResultSet rs = stmt.executeQuery(TestUtil.selectSQL("table1", "smallint_column"));
@@ -387,7 +387,7 @@ public class GetObjectTest {
    */
   @Test
   public void testGetShortNull() throws SQLException {
-    Statement stmt = _conn.createStatement();
+    Statement stmt = conn.createStatement();
     stmt.executeUpdate(TestUtil.insertSQL("table1","smallint_column","NULL"));
 
     ResultSet rs = stmt.executeQuery(TestUtil.selectSQL("table1", "smallint_column"));
@@ -405,7 +405,7 @@ public class GetObjectTest {
    */
   @Test
   public void testGetInteger() throws SQLException {
-    Statement stmt = _conn.createStatement();
+    Statement stmt = conn.createStatement();
     stmt.executeUpdate(TestUtil.insertSQL("table1","smallint_column, integer_column","1, 2"));
 
     ResultSet rs = stmt.executeQuery(TestUtil.selectSQL("table1", "smallint_column, integer_column"));
@@ -425,7 +425,7 @@ public class GetObjectTest {
    */
   @Test
   public void testGetIntegerNull() throws SQLException {
-    Statement stmt = _conn.createStatement();
+    Statement stmt = conn.createStatement();
     stmt.executeUpdate(TestUtil.insertSQL("table1","smallint_column, integer_column","NULL, NULL"));
 
     ResultSet rs = stmt.executeQuery(TestUtil.selectSQL("table1", "smallint_column, integer_column"));
@@ -445,7 +445,7 @@ public class GetObjectTest {
    */
   @Test
   public void testGetBigInteger() throws SQLException {
-    Statement stmt = _conn.createStatement();
+    Statement stmt = conn.createStatement();
     stmt.executeUpdate(TestUtil.insertSQL("table1","bigint_column","2147483648"));
 
     ResultSet rs = stmt.executeQuery(TestUtil.selectSQL("table1", "bigint_column"));
@@ -463,7 +463,7 @@ public class GetObjectTest {
    */
   @Test
   public void testGetLong() throws SQLException {
-    Statement stmt = _conn.createStatement();
+    Statement stmt = conn.createStatement();
     stmt.executeUpdate(TestUtil.insertSQL("table1","bigint_column","2147483648"));
 
     ResultSet rs = stmt.executeQuery(TestUtil.selectSQL("table1", "bigint_column"));
@@ -481,7 +481,7 @@ public class GetObjectTest {
    */
   @Test
   public void testGetLongNull() throws SQLException {
-    Statement stmt = _conn.createStatement();
+    Statement stmt = conn.createStatement();
     stmt.executeUpdate(TestUtil.insertSQL("table1","bigint_column","NULL"));
 
     ResultSet rs = stmt.executeQuery(TestUtil.selectSQL("table1", "bigint_column"));
@@ -499,7 +499,7 @@ public class GetObjectTest {
    */
   @Test
   public void testGetDouble() throws SQLException {
-    Statement stmt = _conn.createStatement();
+    Statement stmt = conn.createStatement();
     stmt.executeUpdate(TestUtil.insertSQL("table1","double_column","1.0"));
 
     ResultSet rs = stmt.executeQuery(TestUtil.selectSQL("table1", "double_column"));
@@ -517,7 +517,7 @@ public class GetObjectTest {
    */
   @Test
   public void testGetDoubleNull() throws SQLException {
-    Statement stmt = _conn.createStatement();
+    Statement stmt = conn.createStatement();
     stmt.executeUpdate(TestUtil.insertSQL("table1","double_column","NULL"));
 
     ResultSet rs = stmt.executeQuery(TestUtil.selectSQL("table1", "double_column"));
@@ -535,7 +535,7 @@ public class GetObjectTest {
    */
   @Test
   public void testGetFloat() throws SQLException {
-    Statement stmt = _conn.createStatement();
+    Statement stmt = conn.createStatement();
     stmt.executeUpdate(TestUtil.insertSQL("table1","real_column","1.0"));
 
     ResultSet rs = stmt.executeQuery(TestUtil.selectSQL("table1", "real_column"));
@@ -553,7 +553,7 @@ public class GetObjectTest {
    */
   @Test
   public void testGetFloatNull() throws SQLException {
-    Statement stmt = _conn.createStatement();
+    Statement stmt = conn.createStatement();
     stmt.executeUpdate(TestUtil.insertSQL("table1","real_column","NULL"));
 
     ResultSet rs = stmt.executeQuery(TestUtil.selectSQL("table1", "real_column"));
@@ -571,11 +571,11 @@ public class GetObjectTest {
    */
   @Test
   public void testGetSerial() throws SQLException {
-    if (!((BaseConnection) _conn).haveMinimumServerVersion(ServerVersion.v9_2)) {
+    if (!((BaseConnection) conn).haveMinimumServerVersion(ServerVersion.v9_2)) {
       // smallserial requires 9.2 or later
       return;
     }
-    Statement stmt = _conn.createStatement();
+    Statement stmt = conn.createStatement();
     stmt.executeUpdate(TestUtil.insertSQL("table1","smallserial_column, serial_column","1, 2"));
 
     ResultSet rs = stmt.executeQuery(TestUtil.selectSQL("table1", "smallserial_column, serial_column"));
@@ -595,7 +595,7 @@ public class GetObjectTest {
    */
   @Test
   public void testGetBoolean() throws SQLException {
-    Statement stmt = _conn.createStatement();
+    Statement stmt = conn.createStatement();
     stmt.executeUpdate(TestUtil.insertSQL("table1","boolean_column","TRUE"));
 
     ResultSet rs = stmt.executeQuery(TestUtil.selectSQL("table1", "boolean_column"));
@@ -613,7 +613,7 @@ public class GetObjectTest {
    */
   @Test
   public void testGetBooleanNull() throws SQLException {
-    Statement stmt = _conn.createStatement();
+    Statement stmt = conn.createStatement();
     stmt.executeUpdate(TestUtil.insertSQL("table1","boolean_column","NULL"));
 
     ResultSet rs = stmt.executeQuery(TestUtil.selectSQL("table1", "boolean_column"));
@@ -631,11 +631,11 @@ public class GetObjectTest {
    */
   @Test
   public void testGetBlob() throws SQLException {
-    Statement stmt = _conn.createStatement();
-    _conn.setAutoCommit(false);
+    Statement stmt = conn.createStatement();
+    conn.setAutoCommit(false);
     try {
       byte[] data = new byte[]{(byte) 0xDE, (byte) 0xAD, (byte) 0xBE, (byte) 0xEF};
-      PreparedStatement insertPS = _conn.prepareStatement(TestUtil.insertSQL("table1", "lob_column", "?"));
+      PreparedStatement insertPS = conn.prepareStatement(TestUtil.insertSQL("table1", "lob_column", "?"));
       try {
         insertPS.setObject(1, new SerialBlob(data), Types.BLOB);
         insertPS.executeUpdate();
@@ -659,7 +659,7 @@ public class GetObjectTest {
         rs.close();
       }
     } finally {
-      _conn.setAutoCommit(true);
+      conn.setAutoCommit(true);
     }
   }
 
@@ -668,7 +668,7 @@ public class GetObjectTest {
    */
   @Test
   public void testGetArray() throws SQLException {
-    Statement stmt = _conn.createStatement();
+    Statement stmt = conn.createStatement();
     String[] data = new String[]{"java", "jdbc"};
     stmt.executeUpdate(TestUtil.insertSQL("table1","array_column","'{\"java\", \"jdbc\"}'"));
 
@@ -692,11 +692,11 @@ public class GetObjectTest {
    */
   @Test
   public void testGetXml() throws SQLException {
-    if (!TestUtil.haveMinimumServerVersion(_conn, ServerVersion.v8_3)) {
+    if (!TestUtil.haveMinimumServerVersion(conn, ServerVersion.v8_3)) {
       // XML column requires PostgreSQL 8.3+
       return;
     }
-    Statement stmt = _conn.createStatement();
+    Statement stmt = conn.createStatement();
     String content = "<book><title>Manual</title></book>";
     stmt.executeUpdate(TestUtil.insertSQL("table1","xml_column","XMLPARSE (DOCUMENT '<?xml version=\"1.0\"?><book><title>Manual</title></book>')"));
 
@@ -723,7 +723,7 @@ public class GetObjectTest {
   @Ignore
   @Test
   public void testGetMoney() throws SQLException {
-    Statement stmt = _conn.createStatement();
+    Statement stmt = conn.createStatement();
     String expected = "12.34";
     stmt.executeUpdate(TestUtil.insertSQL("table1","money_column","'12.34'::float8::numeric::money"));
 
@@ -745,7 +745,7 @@ public class GetObjectTest {
    */
   @Test
   public void testGetPoint() throws SQLException {
-    Statement stmt = _conn.createStatement();
+    Statement stmt = conn.createStatement();
     PGpoint expected = new PGpoint(1.0d, 2.0d);
     stmt.executeUpdate(TestUtil.insertSQL("table1","point_column","point '(1, 2)'"));
 
@@ -764,12 +764,12 @@ public class GetObjectTest {
    */
   @Test
   public void testGetLine() throws SQLException {
-    if (!((BaseConnection) _conn).haveMinimumServerVersion(ServerVersion.v9_4)) {
+    if (!((BaseConnection) conn).haveMinimumServerVersion(ServerVersion.v9_4)) {
       // only 9.4 and later ship with full line support by default
       return;
     }
 
-    Statement stmt = _conn.createStatement();
+    Statement stmt = conn.createStatement();
     PGline expected = new PGline(1.0d, 2.0d, 3.0d);
     stmt.executeUpdate(TestUtil.insertSQL("table1","line_column","line '{1, 2, 3}'"));
 
@@ -788,7 +788,7 @@ public class GetObjectTest {
    */
   @Test
   public void testGetLineseg() throws SQLException {
-    Statement stmt = _conn.createStatement();
+    Statement stmt = conn.createStatement();
     PGlseg expected = new PGlseg(1.0d, 2.0d, 3.0d, 4.0d);
     stmt.executeUpdate(TestUtil.insertSQL("table1","lseg_column","lseg '[(1, 2), (3, 4)]'"));
 
@@ -807,7 +807,7 @@ public class GetObjectTest {
    */
   @Test
   public void testGetBox() throws SQLException {
-    Statement stmt = _conn.createStatement();
+    Statement stmt = conn.createStatement();
     PGbox expected = new PGbox(1.0d, 2.0d, 3.0d, 4.0d);
     stmt.executeUpdate(TestUtil.insertSQL("table1","box_column","box '((1, 2), (3, 4))'"));
 
@@ -826,7 +826,7 @@ public class GetObjectTest {
    */
   @Test
   public void testGetPath() throws SQLException {
-    Statement stmt = _conn.createStatement();
+    Statement stmt = conn.createStatement();
     PGpath expected = new PGpath(new PGpoint[]{new PGpoint(1.0d, 2.0d), new PGpoint(3.0d, 4.0d)}, true);
     stmt.executeUpdate(TestUtil.insertSQL("table1","path_column","path '[(1, 2), (3, 4)]'"));
 
@@ -845,7 +845,7 @@ public class GetObjectTest {
    */
   @Test
   public void testGetPolygon() throws SQLException {
-    Statement stmt = _conn.createStatement();
+    Statement stmt = conn.createStatement();
     PGpolygon expected = new PGpolygon(new PGpoint[]{new PGpoint(1.0d, 2.0d), new PGpoint(3.0d, 4.0d)});
     stmt.executeUpdate(TestUtil.insertSQL("table1","polygon_column","polygon '((1, 2), (3, 4))'"));
 
@@ -864,7 +864,7 @@ public class GetObjectTest {
    */
   @Test
   public void testGetCircle() throws SQLException {
-    Statement stmt = _conn.createStatement();
+    Statement stmt = conn.createStatement();
     PGcircle expected = new PGcircle(1.0d, 2.0d, 3.0d);
     stmt.executeUpdate(TestUtil.insertSQL("table1","circle_column","circle '<(1, 2), 3>'"));
 
@@ -883,7 +883,7 @@ public class GetObjectTest {
    */
   @Test
   public void testGetInterval() throws SQLException {
-    Statement stmt = _conn.createStatement();
+    Statement stmt = conn.createStatement();
     PGInterval expected = new PGInterval(0, 0, 3, 4, 5, 6.0d);
     stmt.executeUpdate(TestUtil.insertSQL("table1","interval_column","interval '3 4:05:06'"));
 
@@ -902,11 +902,11 @@ public class GetObjectTest {
    */
   @Test
   public void testGetUuid() throws SQLException {
-    if (!TestUtil.haveMinimumServerVersion(_conn, ServerVersion.v8_3)) {
+    if (!TestUtil.haveMinimumServerVersion(conn, ServerVersion.v8_3)) {
       // UUID requires PostgreSQL 8.3+
       return;
     }
-    Statement stmt = _conn.createStatement();
+    Statement stmt = conn.createStatement();
     String expected = "a0eebc99-9c0b-4ef8-bb6d-6bb9bd380a11";
     stmt.executeUpdate(TestUtil.insertSQL("table1","uuid_column","'" + expected + "'"));
 
@@ -925,7 +925,7 @@ public class GetObjectTest {
    */
   @Test
   public void testGetInetAddressNull() throws SQLException, UnknownHostException {
-    Statement stmt = _conn.createStatement();
+    Statement stmt = conn.createStatement();
     stmt.executeUpdate(TestUtil.insertSQL("table1","inet_column","NULL"));
 
     ResultSet rs = stmt.executeQuery(TestUtil.selectSQL("table1", "inet_column"));
@@ -943,7 +943,7 @@ public class GetObjectTest {
    */
   @Test
   public void testGetInet4Address() throws SQLException, UnknownHostException {
-    Statement stmt = _conn.createStatement();
+    Statement stmt = conn.createStatement();
     String expected = "192.168.100.128";
     stmt.executeUpdate(TestUtil.insertSQL("table1","inet_column","'" + expected + "'"));
 
@@ -962,7 +962,7 @@ public class GetObjectTest {
    */
   @Test
   public void testGetInet6Address() throws SQLException, UnknownHostException {
-    Statement stmt = _conn.createStatement();
+    Statement stmt = conn.createStatement();
     String expected = "2001:4f8:3:ba:2e0:81ff:fe22:d1f1";
     stmt.executeUpdate(TestUtil.insertSQL("table1","inet_column","'" + expected + "'"));
 
